--[[
	Project: SoulEnergyTracker
	Friendly Name: Soul Energy Tracker
	Author:

	File: init.lua
	Purpose: Initialization, Engine Setup

	Version: 10

	ALL RIGHTS RESERVED.
	COPYRIGHT (c)2015 VANDESDELCA32
]]

-- GLOBALS: SLASH_SOULENERGY2, SLASH_SOULENERGY1, SlashCmdList, YES,
-- GLOBALS: NO, SoulEnergyTrackerData, StaticPopupDialogs, StaticPopup_Show, WeakAuras
-- GLOBALS: OKAY, ReloadUI

local tconcat, tostringall, format = table.concat, tostringall, format

local AddonName, Engine = ...

local MyAddon = LibStub("AceAddon-3.0"):NewAddon(AddonName, "AceEvent-3.0", "AceTimer-3.0", "AceComm-3.0", "AceSerializer-3.0")
LibStub("LibVan32-1.0"):Embed(MyAddon, AddonName)

------------------
-- Debug Functions
------------------
function MyAddon.printFuncName(func, ...)
	local argList = tconcat({tostringall(...)}, "§r,§6 ")
	return MyAddon:PrintDebug("§a" .. func .. "§f(§6" .. (argList or "") .. "§f)")
end

MyAddon._Major = "release_v2.0.4"
MyAddon._Revision = "13"
MyAddon._CommPrefix = "SOULTRACKER"

local Defaults = { -- Settings
	_Version = 1,
	_WAImports = false,
	LoginMessage = true,
	Maximum = 250,
	Last_Value = 0,
	Update_Interval = 10,
	Decline = {
		Interval = 120,
		Amount = 1,
		Auto_Rate = 0.01,
	},
	_LastChange = -1,
}

Engine[1] = MyAddon
Engine[2] = LibStub("AceLocale-3.0"):GetLocale(AddonName)
Engine[3] = Defaults

_G["SoulEnergyTracker"] = MyAddon


function MyAddon:OnInitialize()
	self.printFuncName("OnInitialize")
	-- Do init tasks here, like loading the Saved Variables,
	-- or setting up slash commands.
	SLASH_SOULENERGY1 = "/se"
	SLASH_SOULENERGY2 = "/soulenergy"

	-- Importing info and static popups:
	StaticPopupDialogs["SOULENERGY_WEAKAURASIMPORT1"] = {
		text = Engine[2]["Msg/WeakAurasImport1"],
		button1 = YES,
		button2 = NO,
		OnAccept = function(self, data, data2)
			local playerAura = "dm19HaGisQIlrsvTjskkJseDkrYQiPYRqvOzjs1TGk2fK6xKuyyqWXeILHQQNjcnnHKRrQY2Gk13GkzCcPCorLSoskQMhQc6EcPAFOkGdcHSqsv9qrftuuLlsQSruf9rrqLrIQa5KIaRufEjjfrZevLUjjL2jj5NIQYqrvXsfvQNk1urLRksPTcHIVkckJveKZssv6TqOYCfvv3fcL2lYFjrdgCyIwmQspgktMuUmvBgI(SOmAOQtlXQfbv9AiPzRs3wO2nk)MWWvrhNKI0Yv1ZL00PCDbBxKIVdjA8qcNNewpeQ69KueUpQcu7xzkcXrTK4iJ6k18JocAeqhbxuhtTg1Aeh1kYhsKv3iv4Kicu)EwrW4uC6uN9IWj1v)IKpIcZOw)8XXLp1YxD8KJAKVm2B7LMKuLi1okoLmnxJ0NAwiM7lzz(xjvrOUOrDlc3b6y(NPya3lXq1FQVcPgXrTwbjYcw4AkioQJdxRqCKrg1V46eh1XHRvioYiJAKsmRiyeh1XHRvioYiJAtEDMrCuhhUwH4iJmQFjMtCuhhUwH4iJmYOwYWWlE(ikmJAU8XhYOgJ4ivrioQLmm8INpIcZOMlF8HAKcMXZRmRsD(slhFtGkDuZR8ZrCfpXrQIq8uVi5I)eJMErPh)4kXeriQiesC0lrsf)epJsVCfjxiONEiWFurWDUWf)esC0lrsvIepXfc5kx4kx8NOEjIReXfcrWfHeh9sKmQpFr271kFEhRulcgPcbQVcPgXrDO6kFjMt6tDO6kzEA8N4LAtEDMrCuhhUwH4iJmQRfeVtCuxlSSRtntWCQJdxRqCuZemN0NmYOg7kRvIJ6AHLDDQtyik38nF5OMKmQdvx57YBmPp1HQRe7kRvsFQFX1joQJdxRqCKrg1mzStnIyAsNPvQuJuIzfbJ4OooCTcXrgzuRvqISGfUMcIJ64W1kehzKr9lXCIJ6AHLDDQ1)keA6UiPooCTcXrgzuhQUsMm2j9P(D5nM6eMIp(9QnaryyIxJmQFpRiyCkoDQLHxYR8PUAsmuReVuxyftjMi(86MRrQIqT5OWcVtTAlSsS8wQg18kEn)ZhsKv3ivrrTvI9NNcMrTUBAsBcgWtbZOMxXR5Fcyv3ivrOglunrmNJcJAKbgMveSKP2XGbdg8UfE2a1J6zhotJASq1eXCokS0EQjnNApnoZOwYkXsRiyeh1vt(gXrTP40P(89QBuF(E1nQR3IMBItQ1cV0kcMstXPt97xPvsJtg1XYcJ4O(89QBuFgUvNmQrwyLkEIJAtXPt957v3O(89QBuxVfn3eNKrg12xYY8N4OouDLbwXi9PouDLYR)gNItN0NAtXPtnwOAIyQdmpnoZO2kXUg1yHQjIvIVO5uJfQMiMApnoZOoh8sBGA9AvM5uJfQMiUnjgQvQPglunrCEHxAfbJACWzqEHxAfbBqHHuSdCWzGA27QPHY71bjo4Dl8SQA(aSW)oZsFqSefL4qC6dcvNfI51)6oqgyywrWsIgn6u7yWGbdUcm5DqRtPArucni6dAr4QJ5FMcUxIHQ)5jnjA1krrjoeVJbdgm4kWK3bToL5K2CNBDQ4ge9bTiC1X8ptb3lXq1F05e(3zgIrEd(ogmyWGDmyWGbVBHNnO1PmN0M7CRtfx6dADkvlIsO0hyFW3HZ0Oglunrm14GZaUVKL5)oqgyywrWsIgn6u7yWGbdkihWe2GeWYreZR04RadvnbkzjtnWW7SDmyWGbdgmyW7w4zdAr4QJ5FMcUxIHQ)Ov24fOuF5VJbdgmWzA7WzAuJfQMiwPP40PUAsluPgdVJHk1HtnP5KrT5OWiEPgVxYWBKQiiqTvI9NNxzwL68Lwo(Mav6O2eM8YN3Xk1IGrQqG6aZ(swM)eh1yHQjIPghCgKwM9LSm)3bYadZkcws0OrNAhdgmyqb5GeWYreZR04RadvnbkzjtnWW7Sb7yWGbdgmyWG3TWZgyFW3XGbdg43QVJbdgmyWGbdE3cpBatydAr4QJ5FMcUxIHQ)Ov24fOuF5VJbdgmWzA7WzAKrDbtWiEP2kX(t8snVIxZFDAzo16FliEeV81gKxrEfzuZR418VliENufHFQlycMYArZPMV64jh18kEn)ZrCfpXrQIIufHmQLAAfRiyYRs7lzz(xjoYOMxXR5V(smu1EXj1QemN6Ig1TiChOJ5FMcQTsS)DbX7KQirOgLfndpPkreqGAwiM7lzz(xjvriJuXpXrnkYhsKv3iviGgbeqis0smcc6ffUJgU0J6aZ(swM)eh1yHQjIPghCgKwM9LSm)3bYadZkcws0OrNAhdgmyqb5aMWg0IWvhZ)mfCVedv)rRSXlqP(YFGH3zdE3cpBG9bFGZ02XGbdgCfyY7GwNYCsFqRtzEdI(GweU6y(NPG7LyO6p6Cc)7mdXiVbp9bTiC1X8ptb3lXq1)8KMeDEo2TWC0ikwey2ogmyWGcYbjGLJiMxPXxbgQAcuYsMAGH3z7yWGbdgmyWG3TWZgyFW3XGbdg43QxqoO1PmNb8ads26uM3a1niXudm8oBhdgmyWGbdg8UfE2a7d(ogmyWa)w9cYbToL5nGhoaHbgENTJbdgmyWGbdE3cpBG9bFhdgmyGFREb5aMWg0IWvhZ)mfCVedv)rRSXlqP(YFGH3z7yWGbdgmyWG3TWZgyFW3XGbdg4mTD4mnYO(9SIGXP40P2CuyH3PM3RZ0uRqZPgr5Lh1fwXuIjIpVU5AKQiulXSIGvjoQRM8nIJ6QiW0uIHxYy(LA1kRM)uRjuIfQMiM4L6QiW0OobmZFKsmp)isttWQ5VXlFxtTUwrQuTkuRRvK5VkcmT8Zxoo(OKVcuYdYLxdpArwg1AcLvrGPr8sg1fwXioQ1ekXcvtet8sgzuBokSW7uNaM5psjMNFePPjy18NWCjQik8YA(5JaL(JOWlRQ11kY8JOWlR5hrHxIBCtnM4kEIJuXpXZOHl9YvUII)OHqu4occrtp9iK4ONEKQejEgv0WvurfTOseb(1d36Hl(rGqIJErrg1fnQBr4oqhZ)mfd4RaLdq01FJAjRelTIGrCuxn5Beh1MItN6Z3RUr957v3OgPuZjJ6yzHrCuJjUIp3KQiuhQUYxysZj9Pwl8sRiyuNi1Y7jEjNItNA59eVKpHB1PgtCfV(KQiuJjUIpHJufHA59eVKNbgg1dgmyW7w4zdqgyywrWsE(IS3R10hun5BPpqZVMm1ogmyWGbdUcm5DGKLD9brFqYZxK9EToqDd4FG6geln8OplPgGZGKXsdp6ZYa1ya)P2XGbdgmyW7w4zdQM8Tb84GKjtgln8ORfwsjl76PgWJdIKsn4p1a1nqZVMm1ogmyWaNPTJbdOouDLY7jEjXl1MItNASq1eXuxXKxNNbgg1dgmyW7w4zdqgyywrWsE(IS3R10hun5Bju6dQM8n1B6dQyYRNqPpOIjVU6n1ogmyWGbdUcm5DGKLD9brFqYZxK9EToqDd4FG6geln8OplPgGZGKXsdp6ZYa1ya)P2XGbdgmyW7w4zdQM8TeAapoizYKXsdp6AHLuYYUEQb84GiPud(tnqDdswXKxpHgGZGiPsL(GQjFt9oGhhKmzYyPHhDTWskzzxp1aECqKuQb)PgOUbjRyYRREhGZGiPsTJbdgmWzA7yWaQRyYRZP40P(mCRo1VWKMZZadJ6bdgm4Dl8SbidmmRiyjpFr271A6dQM8T0hO5xtMAhdgmyWvGjVdoFr2ogmyWGcYKNVi79ADapCacO5xVudm8oBhdgmyWGbNViBq0hC(IS3R1bQBqu7yWGbdgmWVvVGm55lYEVwhWdhGgx6LAGH3z7yWGbdgm48fzdI(a(hGZGKNVi79ADG6gevQDmyWGb(T67yWGbdgm48fzdI(GKNVi79ADaodIKAG6ge1ogmyWaNPTJbdgm4Dl8Sbvt(2aECqYZxKnqDd08RjtTJbdgmWzA7yWaQpFV6g1Y7jEjFc3QtT8EIxsQqanUPouDLvm51jEPwbPcbQrbPcbQFHjnNtXPtnVsmuLmnKI3WtnM4kEerQIqDftEDfKQiOJq9lmP5KQerG6kM86OGufbDeYOgzHvQ4joQnfNo1NVxDJ6Z3RUrnsPMtgzuBFjlZFIJAtXPtnwOAIyQXcvteReFrZP2kXUg1bMNgNzuldMGASq1eXknfNo1vtAHk1yHQjIPghCgW9LSm)3bYadZkcws0OrNAhdgmyqb5aMWg0IWvhZ)mfCVedv)rRSXlqP(YFGH3zdE3cpBas5T6dCM2ogmyWGRatEh06uMt6dADkZBq0h0IWvhZ)mfCVedv)rNt4FNzig5n4PpOfHRoM)zk4EjgQ(NN0KOZZXUfMJgrXIaZ2XGbdguqoGjSbjGLJiMxPXxbgQAcuYsMAGH3z7yWGbdgmyWGcYbToL5mGhg9bjBDkZBG6gKyQbsM2GwNY8gWdmaHbgENTJbdgmyWGbdgmyWG3TWZgyFW3XGbdgmyWGbotBhdgmyGZ02HZ0OouDLbwXi9PgdVJHk1HtnP5KrTMxLw4LMt6tnleZ9LSm)RKQiuFfsnIJ6q1vY804pXl1M86mJ4OooCTcXrgzuRvqISGfUMcIJ64W1kehzKr9lXCIJ64W1kehzKrnsjMvemIJ64W1kehzKr9lUoXrDC4AfIJmYiJAf5djYQBKQiiqgPkrIJ6aZ(swM)eh1yHQjIPghCgKwM9LSm)3bYadZkcws0OrNAhdgmyqb5aMWg0IWvhZ)mfCVedv)rRSXlqP(YFGH3zdE3cpBG9bFGZ02XGbdgCfyY7GwNYCsFqRtzEdI(GweU6y(NPG7LyO6p6Cc)7mdXiVbp9bTiC1X8ptb3lXq1)8KMeDEo2TWC0ikwey2ogmyWGcYbjGLJiMxPXxbgQAcuYsMAGH3z7yWGbdgmyWG3TWZgyFW3XGbdg43QxqoGjSbTiC1X8ptb3lXq1F0kB8cuQV8hy4D2ogmyWGbdgm4Dl8Sb2h8DmyWGb(T6fKdADkZBapWaegy4D2ogmyWGbdgm4Dl8Sb2h8DmyWGbotBhotJmQFpRiyCkoDQnhfw4DQ596mn1k0CQruE5rTI8Hez1nsveeOUWkMsmr851nxJufHAZrHfEN6eWm)rkX88JinnbRM)eMlrfrHxwZpFeO0FefEzvTUwrMFefEzn)ik8sCJBQrr(qIS6gPcb0iGacrIwIrqqVOWD0WLEuBFjlZFIJAtXPtnwOAIyQdmpnoZOwgmb1yHQjIPghCgW9LSm)3bYadZkcws0OrNAhdgmyqb5aMWg0IWvhZ)mfCVedv)rRSXlqP(YFGH3zdE3cpBas5T6dCM2ogmyWGRatEh06uMt6dADkZBq0h0IWvhZ)mfCVedv)rNt4FNzig5n4PpOfHRoM)zk4EjgQ(NN0KOZZXUfMJgrXIaZ2XGbdguqoGjSbjGLJiMxPXxbgQAcuYsMAGH3z7yWGbdgmyWGcYbToL5nGhoaHbgENTJbdgmyWGbdgmyWG3TWZgyFW3XGbdgmyWGbotBhdgmyGZ02HZ02Xo2b1HQRmWkgPp1y4DmuPoCQjnNASq1eXknfNo1vtAHk1yHQjIvIVO5uBLyxJmQLSsS0kcgXrD1KVrCuBkoDQpFV6g1NVxDJAKsnNmQJLfgXrnM4k(CtQIqT8EIxYP40PwEpXl5t4wDQXexXRpPkc1yIR4t4ivrOwEpXl5zGHr9Gbdg8UfE2aKbgMveSKNVi79An9bvt(w6d08RjtTJbdgmyWGRatEhizzxFq0hK88fzVxRdu3a(hOUbXsdp6ZsQb4mizS0WJ(SmqngWFQDmyWGbdg8UfE2GQjFBapoizYKXsdp6AHLuYYUEQb84GiPud(tnqDd08RjtTJbdgmWzA7yWaQdvxP8EIxs6tTP40Pglunrm1vm51vqQIqT8EIxsQqanUPwbPcbQrbPcbQRyYRJcsveQ1cV0kcg1js9lmP5KkeO(89QBulVN4L8jCRo1yIR4rePkczuJSWkv8eh1MItN6Z3RUr957v3OgPuZjJmQlAu3IWDGoM)zkgKBhdV8ZCQzHyUVKL5FLufHAnVkTWlnN0N6RqQrCuhQUsMNg)jEP2KxNzeh1XHRvioYiJATcsKfSW1uqCuhhUwH4iJmQFX1joQJdxRqCKrg1iLywrWioQJdxRqCKrg1VeZjoQJdxRqCKrgzuJjUIN4ivriEgLE8hHFCJq0qG)eXvUWv0WnHeh9IgPkrINrPh)r4h3iene4prCLlCfnCtiXrpCrgzKQOioQrkywxq8oPkccuRvQNxPcohfg1Qpg1yHQjI5CuyuJmWWSIGLenA0P2XGbdgCfyY7aBq0hOManA08G3XGbdguqoWeSqmV(N0qCjIytnqY0gycwiMx)tAiUOqSPgy4D2ogmyWGbdgm4Dl8SbifFS0sQEu)6a1yG6xhKu9ran)ivF1x9v)uQN0hO)7sut7jFLFMRkeZR)1KgIlreBQ0hO)7sut7jFLFMRkeZR)1KgIlkeBQ0hK0qCjIyvddXffIvDdIGacPsTJbdgmWzA7WzAuRiFirwDJufHAtyYlFEhRulcgPcbQlSIPeteFEDZ1ivrO(9SIGXP40P2Cuyux9ls(ikmJ6C0PItxUPoHpuTcsfuNJovC6Yn1swjwAfbJ4OUAY3ioQnfNo1NVxDJATWlTIGP0uC6u)(vAL04uF(E1nQR3IMBItYOgzHvQ4joQnfNo1NVxDJ6Z3RUrD9w0CtCsgzuBFjlZFIJAtXPtnwOAIyQdmpnoZOwgmb1yHQjIBtIHALAQXcvteNx4LwrWOghCgKx4LwrWguyif7ahCgOM9UAAO8EDqIdE3cpRQMpal8VZS0helrrjoeN(Gq1zHyE9VUdKbgMveSKOrJo1ogmyWGRatEh06uQweLqdI(GweU6y(NPG7LyO6FEstIwTsuuIdX7yWGbdUcm5DqRtzoPn35wNkUbrFqlcxDm)ZuW9smu9hDoH)DMHyK3GVJbdgmyhdgmyW7w4zdADkZjT5o36uXL(GwNs1IOek9b2h8D4mnQdvxzGvmsFQXcvtetno4mG7lzz(VdKbgMveSKOrJo1ogmyWGcYbmHnibSCeX8kn(kWqvtGswYudm8oBhdgmyWGbdg8UfE2GweU6y(NPG7LyO6pALnEbk1x(7yWGbdCM2oCMg1y4DmuPoCQjnNASq1eXknfNo1vtAHk1yHQjIvIVO5uBLyxJmQdm7lzz(tCuJfQMiMACWzqAz2xYY8FhidmmRiyjrJgDQDmyWGbfKdsalhrmVsJVcmu1eOKLm1adVZgSJbdgmyWGbdE3cpBG9bFhdgmyGFR(ogmyWGbdgm4Dl8SbmHnOfHRoM)zk4EjgQ(JwzJxGs9L)ogmyWaNPTdNPrg1iFzS32lnjPkkQrzrZWt8uVOffc4oc)8JqUIKlCHGE4MqItu4M6ZxK9ETYN3Xk1IGrQqGAKcMrTUBAsBcgWNck8l1Sqm3xYY8VsQIqnEVKH3iEQhU5px6fvKOIGqKOIIF9WnHeNOYf1xHuJ4OouDLmpn(t8sTjVoZioQJdxRqCKrg1AfKilyHRPG4OooCTcXrgzu)IRtCuhhUwH4iJmQrkXSIGrCuhhUwH4iJmQFjMtCuhhUwH4iJmYOUOrDlc3b6y(NPyaNJcBaF8hZzgzKrDAivrII)iKre"
			WeakAuras.ImportString(playerAura)
			StaticPopup_Show("SOULENERGY_IMPORTCOMPLETE1")
			SoulEnergyTrackerData._WAImports = true
		end,
		OnCancel = function(self, data, reason)
			if reason ~= "override" then
				SoulEnergyTrackerData._WAImports = true
				end
			end,
		whileDead = true,
		timeout = 0,
		hideOnEscape = true,
	}

	StaticPopupDialogs["SOULENERGY_IMPORTCOMPLETE1"] = {
		text = format(Engine[2]["Msg/ConfirmImport"], OKAY),
		button1 = OKAY,
		timeout = 0,
		whileDead = true,
		OnAccept = function(self, data, data2)
			StaticPopup_Show("SOULENERGY_WEAKAURASIMPORT2")
		end
	}

	StaticPopupDialogs["SOULENERGY_WEAKAURASIMPORT2"] = {
		text = Engine[2]["Msg/WeakAurasImport2"],
		button1 = YES,
		button2 = NO,
		OnAccept = function(self, data, data2)
			local targetAura = "d80VsaGirOlrPWMOkPmkqXPauRIQeLzPcClkHDrj9lPuWWaLoMkQLjcEgvrtJQW1Ok12ae9nIKghGW5qQQ1jLI6DsPq3tkvhufulKi1drQmrQs4IuQ2isrJukf5KejwPu8sQsKMjG0nvHStq1pPuAOifwQkupvYub5QuI2kvjXxLsPmwPuYBrQYDrkzVq)venyuhMWIvrEmsMmrDzHndWNPQgTi50uz1uLiEnry2s1TbA3i(nfdxK64uLKwUQEUknDsxxuBhPuFNsrJNi68sjRxfK3lLs18PkP6(uLOA)kJNriSeieQyDXkbRNTcR1ZsflqSKXsgHWssBba4gkcpbPcey1YwaaUHIWplvyXsqOszEAyCeflPTfcY2JWkKmTGihYO0yDJoaAyCeflPTfcY2JaQDAcHLqw2Podr0tQVZ3p(lcHkwF47meOwPdS8FtonwaEbyu6lubc3dSizqO357h)fHFgRUriJqyj7aaWrL7AleclWCxDieQOI1B6bcHfyURoecvuXcGGsDgccHfyURoecvuXsf9GOiewG5U6qiurfRxqfiewG5U6qiurfvSCYyvMCFSDs8(Tgd9ckjIFmmQ49dfyuXIcHq4NriS0qsLMDH)fRJSfUT01Mo22JS71T1siGkf42XsqOszEAyCefliBPbwokdbpHfadrPzx4FXYwlHaQuGBhRtINot38iec)mstVpt)e8ei82dVtqQE6jSECgbyH3EIWtaPPhEt)Z0hwV9g2e84mqsFPMacWcV9eH7jstPcl9PVuPFcE6TNs1tPc7zPIaSWBprfR0VX)J7LgFq5UodbHdlwDJqgHWkFJKVGkqPXkFJKKG2XJNWsf9GOiewG5U6qiurfRR7qbcH11r87bwedjWcm3vhcHfXqcuAurfR8nsseGbknwVPhiewG5U6qiurfR8nss1f3lknwVGkqiSUoIFpWs6UXiBVdalWCxDieQOIfragyDyISiiYUlwaeuQZqqiSaZD1HqOIkw5BK8drheLglzhaaoQCxBHqybM7QdHqfvSO6I7fHW66i(9aR22HpgO2sNxkQy9HOdIvBR1d(XvhFykkZlJkwF47meOwPdSe5xCs8yDvbLex8ewoIttszat3dnKr4NXsdj18hyDKJ4afD3vXsdjvAAikw2702sPmMgojJowQdmEAAikw2702sPmMgojJowNmVC8sHCdfHFgRtMxoEPfusi)M0yb3qcSOYx1acfsQybitOuNHadWRz84XJ)qZpzCIjUMGiJLS7MUlAbfsQanaOyzJ0yjioqH6meecRRkEfHWk9h3qX62DYXjJQgqSKZVqDgssTv6aRp6c1r7avSafoccHv6pUHIv6C)gOIfahXDtHqyL(JBOyD7o54KrvdiQOIL(oF)4riSY3iPOhVc1kDGsJfv(QgWKPCYbwu5RAaXsBLoWIkFvdiwzsq7GOyPoWqgR8nsMjofLgRG2brXIUucD8rX9k8dSOYx1awQGsIlwyrLVQb0lYVqDgcwwyXyVi)c1ziJDeaM1yHfJ9AF4vZUpUJ9C8hA(j328yQ8)brpymOqshyg8GX5BqYGNI)UgazcL6meySA1kWRz84XJ7gkrFmragJBFSLeNcxagWKOkE)qte41mE84XDdLOpwwOIXTpUm5UDs8(TGEbLeXBLobvQGEebyqR1mE84XRz84XJDagtm6yIamgB(XeJowwOIXAQGmEnJhpE84XJh)HMFYyypymShmw)C0ghVMXJhpoiYRz84XJxZ4XJh3nuI(4YEYJoCBnU9XYcvy9iHKoWm4AgpE84UHs0hx2tsNLhFSD4qJBFSSqfwPl)FquVIONJ1mE84XRz84XJ)qZpzCzpjDwE8X2HdDW4YEYJoCBDWy9ZXAcImwu5RAaXYclgd9oF)4xdGmHsDgcmwTAf41mE84XDdLOpMiaJXTp2sItHladysufVFOjc8AgpE84UHs0hlluX42hxMC3ojE)wqVGsI4TsNGkvqpIamO1AgpE8yhGXeJowke6mGNekqnusiBSjbgGhliYJLfQySMkiRz84XJhpE84p08tgxMC3ojE)wqVGsI4TMSszSP0IFnJhpECqKxtqKXIkFvdysTv6aRRk08flQubLeyLtll0avS0qsfpHL6aJhpHL6aJNMDH)fRJSfUT01Mo22JS71T1siGkf42Xkv48tPiCpXsdj1YDOaHFgwSOYx1acfsQwMwwObwbTdIILS7MUlAbfsQh78tPyzdfRtMxoE7Y(bws3Dh6qIxESx4eDJpwKmi0789J)IWpJ1jZlhF5ouGWpNawokdj51jhybu70ecRtMxoE6mDZJqiCpq4Nrfl1bgF5ouGWpdlwzI(oF)4riSOYx1aILfwm2sI(oF)4xdGmHsDgcmwTAf41mE84XDdLOpMiaJXTp2sItHladysufVFOjc8AgpE8yhGXsHqNb8KqbQHsczJnjWa8yZpMy0Xebym28JjgDCzYD7K49Bb9ckjI3kDcQub9icWGwJ1ubz8AgpE84XJhp(dn)KX6NJ1mE84Xr)gRz84XJhpE84p08tgtm64YK72jX73c6fuseV1KvkJnLw8Rz84XJdI8AcImQy5KXcs8(HowAXJLqw2Podr0tQVZ3p(lcHkw20jRPq4jaKabwQrfDA8bL76meeoSyDY8YXBlaa3qr4EGkcpbeclagIwUdfi8ZWILS7MUlAbfsQyzdkSOYx1acfsQybitOuNHaJvRwbEnJhpEC3qj6J1XTpUTB1QvV81mE84XoaJvdjdEkEyu65jTaESGipwnKm4P4HrPNh0c4XAQGSMXJhpE84XJ)qZpzmaZdkuys0g3XTHX24oggBaR1eaydBydBaCIhmw6pesyzAGkE)aEg8u8xyu65jTa(GXs)HqcltduX7hWZGNI)cJsppOfWhmggLEEsR2GsppOLx24ZWclWaVMXJhpoiYRjiYyLj6789JhHWIkFvdiwwyXylj6789JFnaYek1ziWy1QvGxZ4XJh3nuI(yIamg3(yljofUamGjrv8(HMiWRz84XJDaglfcDgWtcfOgkjKn2KadWJn)yIrhteGXyZpMy0XLj3TtI3Vf0lOKiER0jOsf0JiadAnwtfKXRz84XJhpE84p08tgRFowZ4XJhh9BSMXJhpE84XJ)qZpzmXOJltUBNeVFlOxqjr8wtwPm2uAXVMXJhpoiYRjiYOI1h(odbQv6alnKuXQLTaaCdfHNawQrfDA8bL76meeoSy5ionjLbmDp0qgHFglbXbkuNHGqyDvXRiewY5xOodjP2kDG1hDH6ODGv6pUHI1T7KJtgvnGOIfahXDtHqyL(JBOyD7o54KrvdiQOILtgliX7h6yOqsflVK8vDaAHfD2Hdz)ySUrhanmoIIfD2Hdz)ySeYYo1ziIEs9D((XFriuXcWlaJsFHkq4EJLnDYAkKMEdeEaR303t67T3EdeajSEaeial8aiXk9B8)4EPXhuURZqq4WIfadrXYEN2wkLX0Wjz0XIKbHENVF8xe(zS0357hpcHfv(QgWKPCYbwQdmKXsBLoWIkFvdiwu5RAatQTshyDvHMVyLjbTdIILiRgSY3izM4uuASOYx1awQGsIlwyrLVQb0lYVqDgcwwyXyVi)c1ziJDeaM1yHfJ9AF4vZUpUJ9C8hA(j328yQ8)brpymOqshyg8GX5BqYGNI)UgazcL6meySA1kWRz84XJ7gkrFmragJBFSLeNcxagWKOkE)qte41mE84XDdLOpwwOIXTpUm5UDs8(TGEbLeXBLobvQGEebyqR1mE84XRz84XJDagtm6yIamgB(XeJowwOIXAQGmEnJhpE84XJh)HMFYyypymShmw)C0ghVMXJhpoiYRz84XJxZ4XJh3nuI(4YEYJoCBnU9XYcvy9iHKoWm4AgpE84UHs0hx2tsNLhFSD4qJBFSSqfwPl)FquVIONJ1mE84XRz84XJ)qZpzCzpjDwE8X2HdDW4YEYJoCBDWy9ZXAcImwu5RAaXYclgd9oF)4xdGmHsDgcmwTAf41mE84XDdLOpMiaJXTp2sItHladysufVFOjc8AgpE84UHs0hlluX42hxMC3ojE)wqVGsI4TsNGkvqpIamO1AgpE8yhGXeJowke6mGNekqnusiBSjbgGhliYJLfQySMkiRz84XJhpE84p08tgxMC3ojE)wqVGsI4TMSszSP0IFnJhpECqKxtqKXIkvqjbw50YcnqfRuHZpLI00BGmb67bqaKNpNGhEaRNjalcWcpOpwDJqgHWkFJKKG2XJNWsf9GOiewG5U6qiurflzhaaoQCxBHqybM7QdHqfvSEtpqiSaZD1HqOIkwaeuQZqqiSaZD1HqOIkwVGkqiSaZD1HqOIkQOIkw0gHF2JeoJkIa"
			WeakAuras.ImportString(targetAura)
			SoulEnergyTrackerData._WAImports = true
		end,
		OnCancel = function(self, data, reason)
			if reason ~= "override" then
				SoulEnergyTrackerData._WAImports = true
				end
			end,
		whileDead = true,
		timeout = 0,
		hideOnEscape = true,
	}

	StaticPopupDialogs["SOULENERGY_RESETCONFIRM"] = {
		text = Engine[2]["Msg/ConfirmReset"],
		button1 = YES,
		button2 = NO,
		OnAccept = function(self, data, data2)
			SoulEnergyTrackerData = nil
			ReloadUI()
		end,
		showAlert = true,
		whileDead = true,
		hideOnEscape = true,
		timeout = 0
	}

	self:ValidateSettings()

	self:RegisterEvent("PLAYER_TARGET_CHANGED")
	SlashCmdList["SOULENERGY"] = function( ... )
		self:HandleChatCommand(...)
	end
end

function MyAddon:OnEnable()
	self.printFuncName("OnEnable")
	-- Do more initialization here, that really enables the use of your addon.
	-- Register Events, Hook functions, Create Frames, Get information from
	-- the game that wasn't available in OnInitialize

	self:RegisterComm(MyAddon._CommPrefix)

	if self:GetSetting(false, "_LastChange") ~= -1 then
		self:StartUpdating(false)
	end

	self:RunUpdate()

	if WeakAuras then
		-- Ask if the user wants to import the WeakAuras imports.
		if not self:GetSetting(false, "_WAImports") then
			StaticPopup_Show("SOULENERGY_WEAKAURASIMPORT1")
		end
	end

	if self:GetSetting(false, "LoginMessage") then
		self:PrintMessage(format(Engine[2]["Msg/LoginMessage"], self:GetVersion(false, true)))
	end
end


function MyAddon:OnDisable()
	self.printFuncName("OnDisable")
	-- Unhook, Unregister Events, Hide frames that you created.
	-- You would probably only use an OnDisable if you want to
	-- build a "standby" mode, or be able to toggle modules on/off.
	self:StopUpdating()
	self._ShowBar = false
end


